All of lore.kernel.org
 help / color / mirror / Atom feed
* [PATCH] sections: Fix __is_kernel() to include init ranges
@ 2022-01-07  0:13 Helge Deller
  0 siblings, 0 replies; only message in thread
From: Helge Deller @ 2022-01-07  0:13 UTC (permalink / raw)
  To: Linux Kernel, Arnd Bergmann, linux-arch; +Cc: linux-parisc

With CONFIG_KALLSYMS_ALL=y, the function is_ksym_addr() is used to
determine if a symbol is from inside the kernel range. For that the
given symbol address is checked if it's inside the _stext to _end range.

Although this is correct, some architectures (e.g. parisc) may have the
init area before the _stext address and as such the check in
is_ksym_addr() fails.  By extending the range check to include the init
section, __is_kernel() will now detect symbols in this range as well.

This fixes an issue on parisc where addresses of kernel functions in
init sections aren't resolved to their symbol names.

Signed-off-by: Helge Deller <deller@gmx.de>

diff --git a/include/asm-generic/sections.h b/include/asm-generic/sections.h
index 1dfadb2e878d..00566b1fd699 100644
--- a/include/asm-generic/sections.h
+++ b/include/asm-generic/sections.h
@@ -193,12 +193,16 @@ static inline bool __is_kernel_text(unsigned long addr)
  * @addr: address to check
  *
  * Returns: true if the address is located in the kernel range, false otherwise.
  * Note: an internal helper, only check the range of _stext to _end.
  */
 static inline bool __is_kernel(unsigned long addr)
 {
-	return addr >= (unsigned long)_stext &&
-	       addr < (unsigned long)_end;
+	return ((addr >= (unsigned long)_stext &&
+	         addr < (unsigned long)_end) ||
+		(addr >= (unsigned long)__init_begin &&
+		 addr < (unsigned long)__init_end));
 }

 #endif /* _ASM_GENERIC_SECTIONS_H_ */

^ permalink raw reply related	[flat|nested] only message in thread

only message in thread, other threads:[~2022-01-07  0:14 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
@@ -193,12 +193,16 @@ static inline bool __is_kernel_text(unsigned long addr)
  *
  * Returns: true if the address is located in the kernel range, false otherwise.
- * Note: an internal helper, only check the range of _stext to _end.
+ * Note: an internal helper, check the range of _stext to _end,
+ *       and range from __init_begin to __init_end, which can be outside
+ *       of the _stext to _end range.
  */
 static inline bool __is_kernel(unsigned long addr)
2022-01-07  0:13 [PATCH] sections: Fix __is_kernel() to include init ranges Helge Deller

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.